@@ -50,13 +50,17 @@ class Attribute(Field):
         """
 
         if self.nullable:
-            if self.default:
-                return f'{self.name} {self.type_.name} DEFAULT {self.default}'
-            return f'{self.name} {self.type_.name}'
+            null_clause = ''
+        else:
+            null_clause = ' NOT NULL'
+
         if self.default:
-            return (f'{self.name} {self.type_.name} '
-                    f'NOT NULL DEFAULT {self.default}')
-        return f'{self.name} {self.type_.name} NOT NULL'
+            default_clause = f' DEFAULT {self.default}'
+        else:
+            default_clause = ''
+
+        return (f'{self.name} {self.type_.name}'
+                f'{null_clause}{default_clause}')
 
     def __str__(self):
         return self.name
