@@ -588,18 +588,26 @@ class OneToOneRemoteRelationship(ToOneRelationship):
         """Updates the database with the one-to-one (remote) relationship
         specified in a PATCH /{collection} request.
         """
-        stmt = (f'UPDATE data.{self.rtable.name} '
-                f'SET {self.rfkey} = $1 '
-                f'WHERE id=$2')
+        stmt_remove = (f'UPDATE data.{self.rtable.name} '
+                       f'SET {self.rfkey} = NULL '
+                       f'WHERE {self.rfkey}=$1')
+        stmt_add = (f'UPDATE data.{self.rtable.name} '
+                    f'SET {self.rfkey} = $1 '
+                    f'WHERE id=$2')
+        object_id_number = env.obj.id.number
         data_id = env.relationships[self.name]
-        data_id_number = data_id.number
         async with env.lock:
-            log.debug(f'{stmt}: {env.obj.id.number}, {data_id_number}')
-            result = await env.connection.execute(stmt, env.obj.id.number,
-                                                  data_id_number)
-        if result == 'UPDATE 0':
-            env.cancel()
-            raise NonexistentRelationshipIdError()
+            log.debug(f'{stmt_remove}: {object_id_number}')
+            await env.connection.execute(stmt_remove, object_id_number)
+            if data_id:
+                data_id_number = data_id.number
+                log.debug(f'{stmt_add}: {object_id_number}, {data_id_number}')
+                result = await env.connection.execute(stmt_add,
+                                                      object_id_number,
+                                                      data_id_number)
+                if result == 'UPDATE 0':
+                    env.cancel()
+                    raise NonexistentRelationshipIdError()
 
     async def get_to_one_related_data(self, env):
         """Creates the response data member for OneToOneRemoteRelationships.
@@ -984,18 +992,26 @@ class OneToManyRelationship(ToManyRelationship):
         """Updates the database with the one-to-many relationship specified in
         a PATCH /{collection}/{id} request.
         """
-        stmt = (f'UPDATE data.{self.rtable.name} '
-                f'SET {self.rfkey} = $1 '
-                f'WHERE id=ANY($2::UUID[])')
-        data_ids = env.relationships[self.name]
-        data_id_numbers = [data_id.number for data_id in data_ids]
+        stmt_remove = (f'UPDATE data.{self.rtable.name} '
+                       f'SET {self.rfkey} = NULL '
+                       f'WHERE {self.rfkey} = $1')
         async with env.lock:
-            log.debug(f'{stmt}: {env.obj.id.number}, {data_id_numbers}')
-            result = await env.connection.execute(stmt, env.obj.id.number,
-                                                  data_id_numbers)
-        if result == 'UPDATE 0':
-            env.cancel()
-            raise NonexistentRelationshipIdError()
+            log.debug(f'{stmt_remove}: {env.obj.id.number}')
+            await env.connection.execute(stmt_remove, env.obj.id.number)
+            data_ids = env.relationships[self.name]
+            if data_ids:
+                stmt_add = (f'UPDATE data.{self.rtable.name} '
+                            f'SET {self.rfkey} = $1 '
+                            f'WHERE id=ANY($2::UUID[])')
+                data_id_numbers = [data_id.number for data_id in data_ids]
+                log.debug(f'{stmt_add}: {env.obj.id.number}, {data_id_numbers}')
+                result = await env.connection.execute(stmt_add,
+                                                      env.obj.id.number,
+                                                      data_id_numbers)
+                count = int(result[len('UPDATE '):])
+                if count != len(data_id_numbers):
+                    env.cancel()
+                    raise NonexistentRelationshipIdError()
 
     async def get_to_one_related_data(self, env):
         """Creates the response data member for OneToManyRelationships.
@@ -1449,16 +1465,20 @@ class ManyToManyRelationship(ToManyRelationship):
         """Updates the database with the many-to-many relationship specified
         in a PATCH /{collection}/{id} request.
         """
-        stmt = (f'INSERT INTO data.{self.atable.name} '
-                f'({self.lafkey}, {self.rafkey}) '
-                f'VALUES ($1, $2)')
+        stmt_remove = (f'DELETE FROM data.{self.atable.name} '
+                       f'WHERE {self.lafkey}=$1')
+        stmt_add = (f'INSERT INTO data.{self.atable.name} '
+                    f'({self.lafkey}, {self.rafkey}) '
+                    f'VALUES ($1, $2)')
         data_ids = env.relationships[self.name]
         data = [(env.obj.id.number, data_id.number) for data_id in data_ids]
         try:
             async with env.lock:
                 async with env.connection.transaction():
-                    log.debug(f'{stmt}: {data}')
-                    await env.connection.executemany(stmt, data)
+                    log.debug(f'{stmt_remove}: {env.obj.id.number}')
+                    await env.connection.execute(stmt_remove, env.obj.id.number)
+                    log.debug(f'{stmt_add}: {data}')
+                    await env.connection.executemany(stmt_add, data)
         except ForeignKeyViolationError as exc:
             env.cancel()
             raise NonexistentRelationshipIdError() from exc
