@@ -149,6 +149,8 @@ class Json(Type):
 
     @staticmethod
     def from_sql(value):
+        if value is None:
+            return None
         return loads(value)
 
 
