@@ -148,13 +148,17 @@ class Object(Resource):
         stmt = (f'UPDATE data.{self.table.name} '
                 f'SET {column_values} '
                 f'WHERE id = $1')
+        attribute_values = []
+        for attr_name, value in env.attributes.items():
+            attr = self.table.attributes_by_name[attr_name]
+            attribute_values.append(attr.type_.to_sql(value))
         try:
             async with env.lock:
                 async with env.connection.transaction():
                     log.debug(f'{stmt}: {env.obj.id.number}, '
                               f'{env.attributes.values()}, {lfkey_values}')
                     result = await env.connection.execute(
-                        stmt, env.obj.id.number, *env.attributes.values(),
+                        stmt, env.obj.id.number, *attribute_values,
                         *lfkey_values)
             if result == 'UPDATE 0':
                 env.cancel()
@@ -258,7 +262,8 @@ class Object(Resource):
             if col_name == 'id':
                 continue
             if col_name in self.table.attributes_by_name:
-                attributes[col_name] = value
+                attr = self.table.attributes_by_name[col_name]
+                attributes[col_name] = attr.type_.from_sql(value)
             else:  # col_name is a lfkey
                 rel = self.table.relationship_by_lfkey[col_name]
                 relationships[rel.name] = self.to_relationships(rel, value)
